module UU
  module OS
    module VUC

      # Enumeration of HTTP status codes to be returned by controllers.
      class HTTPStatus

        # Standard response for successful HTTP requests. The actual response will depend on the request method used.
        # In a GET request, the response will contain an entity corresponding to the requested resource. In a POST
        # request the response will contain an entity describing or containing the result of the action.
        OK = 200

        #The request has been accepted for processing, but the processing has not been completed. The request might or
        # might not eventually be acted upon, as it might be disallowed when processing actually takes place.
        ACCEPTED = 202

        #The server successfully processed the request, but is not returning any content.
        NO_CONTENT = 204

        # The request cannot be fulfilled due to bad syntax.
        BAD_REQUEST = 400

        # Similar to 403 Forbidden, but specifically for use when authentication is required and has failed or has not
        # yet been provided. The response must include a WWW-Authenticate header field containing a challenge applicable
        # to the requested resource.
        UNAUTHORIZED = 401

        #The request was a valid request, but the server is refusing to respond to it. Unlike a 401 Unauthorized response,
        # authenticating will make no difference. On servers where authentication is required, this commonly means that
        #the provided credentials were successfully authenticated but that the credentials still do not grant the client
        # permission to access the resource (e.g. a recognized user attempting to access restricted content).
        FORBIDDEN = 403

        # The requested resource could not be found but may be available again in the future. Subsequent requests by
        # the client are permissible.
        NOT_FOUND = 404

        # The user has sent too many requests in a given amount of time. Intended for use with rate limiting schemes.
        TOO_MANY_REQUESTS = 429

        # A generic error message, given when no more specific message is suitable.
        INTERNAL_SERVER_ERROR = 500

        # The server either does not recognize the request method, or it lacks the ability to fulfill the request
        NOT_IMPLEMENTED = 501

        # The server is currently unavailable (because it is overloaded or down for maintenance). Generally, this is a
        # temporary state.
        SERVICE_UNAVAILABLE = 503

      end

    end
  end
end
